@@ -15,7 +15,7 @@ fi
 
 for python in $interpreters; do
 	printf -- '\n\n============ Testing %s\n\n' "$python"
-	env CONFGET="$python -m confget" prove t
+	env CONFGET="$python -Wignore::SyntaxWarning -m confget" prove t
 done
 
 printf -- '\n\n============ The TAP tests passed for all Python versions\n\n'
